@@ -93,7 +93,7 @@ class BaseAXUIElement(_a11y.AXUIElement):
    def getFrontmostApp(cls):
       '''getFrontmostApp - Get the current frontmost application.
 
-         Raise a ValueError exception if no GUI applications are found. 
+         Raise a ValueError exception if no GUI applications are found.
       '''
       # Refresh the runningApplications list
       apps = cls._getRunningApps()
@@ -103,9 +103,13 @@ class BaseAXUIElement(_a11y.AXUIElement):
          try:
             if ref.AXFrontmost:
                return ref
-         except (_a11y.ErrorUnsupported, _a11y.ErrorCannotComplete):
+         except (_a11y.ErrorUnsupported,
+                 _a11y.ErrorCannotComplete,
+                 _a11y.ErrorAPIDisabled):
             # Some applications do not have an explicit GUI
             # and so will not have an AXFrontmost attribute
+            # Trying to read attributes from Google Chrome Helper returns
+            # ErrorAPIDisabled for some reason - opened radar bug 12837995
             pass
       raise ValueError('No GUI application found.')
 
@@ -227,9 +231,6 @@ class BaseAXUIElement(_a11y.AXUIElement):
          self._sendKeyWithModifiers(keychr.lower(), [AXKeyCodeConstants.SHIFT])
          return
 
-      # To direct output to the correct application need the PSN:
-      appPsn = self._getPsnForPid(self._getPid())
-
       if (keychr not in self.keyboard):
           self._clearEventQueue()
           raise ValueError('Key %s not found in keyboard layout' % keychr)
@@ -249,6 +250,8 @@ class BaseAXUIElement(_a11y.AXUIElement):
 
       # Post the event to the given app
       if not globally:
+          # To direct output to the correct application need the PSN:
+          appPsn = self._getPsnForPid(self._getPid())
           self._queueEvent(Quartz.CGEventPostToPSN, (appPsn, keyDown))
           self._queueEvent(Quartz.CGEventPostToPSN, (appPsn, keyUp))
       else:
@@ -299,9 +302,6 @@ class BaseAXUIElement(_a11y.AXUIElement):
 
       modFlags = 0
 
-      # To direct output to the correct application need the PSN:
-      appPsn = self._getPsnForPid(self._getPid())
-
       # Press given modifiers
       for nextMod in modifiers:
          if (nextMod not in self.keyboard):
@@ -317,6 +317,8 @@ class BaseAXUIElement(_a11y.AXUIElement):
          if globally:
              self._queueEvent(Quartz.CGEventPost, (0, modEvent))
          else:
+             # To direct output to the correct application need the PSN:
+             appPsn = self._getPsnForPid(self._getPid())
              self._queueEvent(Quartz.CGEventPostToPSN, (appPsn, modEvent))
          # Add the modifier flags
          modFlags += AXKeyboard.modKeyFlagConstants[nextMod]
@@ -403,9 +405,6 @@ class BaseAXUIElement(_a11y.AXUIElement):
       eventButtonUp = getattr(Quartz,
                               'kCGEvent%sUp' % mouseButtons[mouseButton])
 
-      # To direct output to the correct application need the PSN:
-      appPsn = self._getPsnForPid(self._getPid())
-
       # Press the button
       buttonDown = Quartz.CGEventCreateMouseEvent(None,
                                                   eventButtonDown,
