@@ -99,7 +99,7 @@ def log(message, level = logging.DEBUG):
     """
 
     if _ldtp_debug:
-        print message
+        print(message)
     logger.log(level, str(message))
     return 1
 
@@ -130,7 +130,7 @@ def startlog(filename, overwrite = True):
     # Create logging file handler
     _file_logger = logging.FileHandler(os.path.expanduser(filename), _mode)
     # Log 'Levelname: Messages', eg: 'ERROR: Logged message'
-    _formatter = logging.Formatter(u'%(levelname)-8s: %(message)s')
+    _formatter = logging.Formatter('%(levelname)-8s: %(message)s')
     _file_logger.setFormatter(_formatter)
     logger.addHandler(_file_logger)
     if _ldtp_debug:
@@ -367,50 +367,53 @@ def imagecapture(window_name = None, out_file = None, x = 0, y = 0,
 
     return out_file
 
-### WINDOWS
-### XML-RPC.NET doesn't support optional arguments
-### We have to wrap those wrappers locally
-if _ldtp_windows_env:
-    def wait(timeout=5):
-        return _remote_wait(timeout)
-    def waittillguiexist(window_name, object_name = '',
-                         guiTimeOut = 30, state = ''):
-        return _remote_waittillguiexist(window_name, object_name,
-                                        guiTimeOut)
-    
-    def waittillguinotexist(window_name, object_name = '',
-                            guiTimeOut = 30, state = ''):
-        return _remote_waittillguinotexist(window_name, object_name,
-                                           guiTimeOut)
-    def guiexist(window_name, object_name = ''):
-        return _remote_guiexist(window_name, object_name)
-    def launchapp(cmd, args = [], delay = 0, env = 1, lang = "C"):
-        return _remote_launchapp(cmd, args, delay, env, lang)
-    def hasstate(window_name, object_name, state, guiTimeOut = 0):
-        return _remote_hasstate(window_name, object_name, state, guiTimeOut)
-    def selectrow(window_name, object_name, row_text):
-        return _remote_selectrow(window_name, object_name, row_text, False)
-    def getchild(window_name, child_name = '', role = '', parent = ''):
-        return _remote_getchild(window_name, child_name, role, parent)
-    def enterstring(window_name, object_name = '', data = ''):
-        return _remote_enterstring(window_name, object_name, data)
-    def setvalue(window_name, object_name, data):
-        return _remote_setvalue(window_name, object_name, float(data))
-    def grabfocus(window_name, object_name = ''):
-        # On Linux just with window name, grab focus doesn't work
-        # So, we can't make this call generic
-        return _remote_grabfocus(window_name, object_name)
-    def copytext(window_name, object_name, start, end = -1):
-        return _remote_copytext(window_name, object_name, start, end)
-    def cuttext(window_name, object_name, start, end = -1):
-        return _remote_cuttext(window_name, object_name, start, end)
-    def deletetext(window_name, object_name, start, end = -1):
-        return _remote_deletetext(window_name, object_name, start, end)
-    def startprocessmonitor(process_name, interval = 2):
-        return _remote_startprocessmonitor(process_name, interval)
-    def gettextvalue(window_name, object_name, startPosition = 0, endPosition = 0):
-        return _remote_gettextvalue(window_name, object_name, startPosition, endPosition)
-### WINDOWS
+def wait(timeout=5):
+    return _remote_wait(timeout)
+def waittillguiexist(window_name, object_name = '',
+                     guiTimeOut = 30, state = ''):
+    return _remote_waittillguiexist(window_name, object_name,
+                                    guiTimeOut)
+def waittillguinotexist(window_name, object_name = '',
+                        guiTimeOut = 30, state = ''):
+    return _remote_waittillguinotexist(window_name, object_name,
+                                       guiTimeOut)
+def guiexist(window_name, object_name = ''):
+    return _remote_guiexist(window_name, object_name)
+def launchapp(cmd, args = [], delay = 0, env = 1, lang = "C"):
+    return _remote_launchapp(cmd, args, delay, env, lang)
+def hasstate(window_name, object_name, state, guiTimeOut = 0):
+    return _remote_hasstate(window_name, object_name, state, guiTimeOut)
+def selectrow(window_name, object_name, row_text):
+    return _remote_selectrow(window_name, object_name, row_text, False)
+def doesrowexist(window_name, object_name, row_text, partial_match = False):
+    return _remote_doesrowexist(window_name, object_name, row_text, partial_match)
+def getchild(window_name, child_name = '', role = '', parent = ''):
+    return _remote_getchild(window_name, child_name, role, parent)
+def enterstring(window_name, object_name = '', data = ''):
+    return _remote_enterstring(window_name, object_name, data)
+def setvalue(window_name, object_name, data):
+    return _remote_setvalue(window_name, object_name, float(data))
+def grabfocus(window_name, object_name = ''):
+    # On Linux just with window name, grab focus doesn't work
+    # So, we can't make this call generic
+    return _remote_grabfocus(window_name, object_name)
+def copytext(window_name, object_name, start, end = -1):
+    return _remote_copytext(window_name, object_name, start, end)
+def cuttext(window_name, object_name, start, end = -1):
+    return _remote_cuttext(window_name, object_name, start, end)
+def deletetext(window_name, object_name, start, end = -1):
+    return _remote_deletetext(window_name, object_name, start, end)
+def startprocessmonitor(process_name, interval = 2):
+    return _remote_startprocessmonitor(process_name, interval)
+def gettextvalue(window_name, object_name, startPosition = 0, endPosition = 0):
+    return _remote_gettextvalue(window_name, object_name, startPosition, endPosition)
+def getcellvalue(window_name, object_name, row_index, column = 0):
+    return _remote_getcellvalue(window_name, object_name, row_index, column)
+def getcellsize(window_name, object_name, row_index, column = 0):
+    return _remote_getcellsize(window_name, object_name, row_index, column)
+def getobjectnameatcoords(waitTime = 0):
+    # FIXME: Yet to implement in Mac, works on Windows/Linux
+    return _remote_getobjectnameatcoords(waitTime)
 
 def onwindowcreate(window_name, fn_name, *args):
     """
@@ -462,7 +465,7 @@ def registerevent(event_name, fn_name, *args):
     @rtype: integer
     """
     if not isinstance(event_name, str):
-        raise ValueError, "event_name should be string"
+        raise ValueError("event_name should be string")
     _pollEvents._callback[event_name] = [event_name, fn_name, args]
     return _remote_registerevent(event_name)
 
@@ -497,7 +500,7 @@ def registerkbevent(keys, modifiers, fn_name, *args):
     @return: 1 if registration was successful, 0 if not.
     @rtype: integer
     """
-    event_name = u"kbevent%s%s" % (keys, modifiers)
+    event_name = "kbevent%s%s" % (keys, modifiers)
     _pollEvents._callback[event_name] = [event_name, fn_name, args]
     return _remote_registerkbevent(keys, modifiers)
 
@@ -514,7 +517,7 @@ def deregisterkbevent(keys, modifiers):
     @rtype: integer
     """
 
-    event_name = u"kbevent%s%s" % (keys, modifiers)
+    event_name = "kbevent%s%s" % (keys, modifiers)
     if event_name in _pollEvents._callback:
         del _pollEvents._callback[event_name]
     return _remote_deregisterkbevent(keys, modifiers)
@@ -545,9 +548,9 @@ def windowuptime(window_name):
     return None
 
 _populateNamespace(globals())
-#_pollEvents = PollEvents()
-#thread.start_new_thread(_pollEvents.run, ())
-#_pollLogs = PollLogs()
-#thread.start_new_thread(_pollLogs.run, ())
+_pollEvents = PollEvents()
+thread.start_new_thread(_pollEvents.run, ())
+_pollLogs = PollLogs()
+thread.start_new_thread(_pollLogs.run, ())
 
 atexit.register(client._client.kill_daemon)
