@@ -29,7 +29,7 @@ class Table(Utils):
     def getrowcount(self, window_name, object_name):
         """
         Get count of rows in table object.
-        
+
         @param window_name: Window name to look for, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -48,7 +48,7 @@ class Table(Utils):
     def selectrow(self, window_name, object_name, row_text):
         """
         Select row
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -80,7 +80,7 @@ class Table(Utils):
     def selectrowpartialmatch(self, window_name, object_name, row_text):
         """
         Select row partial match
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -112,7 +112,7 @@ class Table(Utils):
     def selectrowindex(self, window_name, object_name, row_index):
         """
         Select row index
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -144,7 +144,7 @@ class Table(Utils):
     def selectlastrow(self, window_name, object_name):
         """
         Select last row
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -172,7 +172,7 @@ class Table(Utils):
                      column=0, data=None):
         """
         Set cell value
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -180,9 +180,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
         @param data: data, default value None
                 None, used for toggle button
         @type data: string
@@ -195,7 +195,7 @@ class Table(Utils):
     def getcellvalue(self, window_name, object_name, row_index, column=0):
         """
         Get cell value
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -203,9 +203,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
 
         @return: cell value on success.
         @rtype: string
@@ -226,10 +226,10 @@ class Table(Utils):
             obj=cell.AXChildren[column]
         return obj.AXValue
 
-    def rightclick(self, window_name, object_name, row_text):
+    def getcellsize(self, window_name, object_name, row_index, column=0):
         """
-        Right click on table cell
-        
+        Get cell size
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -237,9 +237,41 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
+
+        @return: cell coordinates on success.
+        @rtype: list
+        """
+        object_handle=self._get_object_handle(window_name, object_name)
+        if not object_handle.AXEnabled:
+            raise LdtpServerException(u"Object %s state disabled" % object_name)
+
+        count=len(object_handle.AXRows)
+        if row_index < 0 or row_index > count:
+            raise LdtpServerException('Row index out of range: %d' % row_index)
+        cell=object_handle.AXRows[row_index]
+        count=len(cell.AXChildren)
+        if column < 0 or column > count:
+            raise LdtpServerException('Column index out of range: %d' % column)
+        obj=cell.AXChildren[column]
+        if not re.search("AXColumn", obj.AXRole):
+            obj=cell.AXChildren[column]
+        return self._getobjectsize(obj)
+
+    def rightclick(self, window_name, object_name, row_text):
+        """
+        Right click on table cell
+
+        @param window_name: Window name to type in, either full name,
+        LDTP's name convention, or a Unix glob.
+        @type window_name: string
+        @param object_name: Object name to type in, either full name,
+        LDTP's name convention, or a Unix glob. 
+        @type object_name: string
+        @param row_text: Row text to right click
+        @type row_text: string
 
         @return: 1 on success.
         @rtype: integer
@@ -249,7 +281,7 @@ class Table(Utils):
     def checkrow(self, window_name, object_name, row_index, column = 0):
         """
         Check row
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -257,9 +289,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
 
         @return: cell value on success.
         @rtype: string
@@ -269,7 +301,7 @@ class Table(Utils):
     def expandtablecell(self, window_name, object_name, row_index, column = 0):
         """
         Expand or contract table cell
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -277,9 +309,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
 
         @return: cell value on success.
         @rtype: string
@@ -289,7 +321,7 @@ class Table(Utils):
     def uncheckrow(self, window_name, object_name, row_index, column = 0):
         """
         Check row
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -297,9 +329,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column: Column index to get, default value 0
-        @type column: index
+        @type column: integer
 
         @return: 1 on success.
         @rtype: integer
@@ -309,7 +341,7 @@ class Table(Utils):
     def gettablerowindex(self, window_name, object_name, row_text):
         """
         Get table row index matching given text
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -337,7 +369,7 @@ class Table(Utils):
     def singleclickrow(self, window_name, object_name, row_text):
         """
         Single click row matching given text
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -354,8 +386,8 @@ class Table(Utils):
 
     def doubleclickrow(self, window_name, object_name, row_text):
         """
-        Single click row matching given text
-        
+        Double click row matching given text
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -374,7 +406,7 @@ class Table(Utils):
                         column_index, row_text):
         """
         Verify table cell value with given text
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -382,9 +414,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column_index: Column index to get, default value 0
-        @type column_index: index
+        @type column_index: integer
         @param row_text: Row text to match
         @type string
 
@@ -403,7 +435,7 @@ class Table(Utils):
                      partial_match = False):
         """
         Verify table cell value with given text
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -438,7 +470,7 @@ class Table(Utils):
                                column_index, row_text):
         """
         Verify partial table cell value
-        
+
         @param window_name: Window name to type in, either full name,
         LDTP's name convention, or a Unix glob.
         @type window_name: string
@@ -446,9 +478,9 @@ class Table(Utils):
         LDTP's name convention, or a Unix glob. 
         @type object_name: string
         @param row_index: Row index to get
-        @type row_index: index
+        @type row_index: integer
         @param column_index: Column index to get, default value 0
-        @type column_index: index
+        @type column_index: integer
         @param row_text: Row text to match
         @type string
 
